@@ -3,28 +3,19 @@ import traceback
 
 
 class Handler:
-  """The ``laboro.error.handler.Handler`` is a singleton that logs every errors given to its ``handle_error()`` method as critical then exit with code 1.
-
-  This object is useful with object with runtime context.
-
-  ..  code-block:: python
-
-      from laboro.error.handler import Handler
-
-      class FakeObj:
-        def __enter__(self):
-          pass
-
-        def __exit__(self, kind, value, trace):
-          Handler.handle_error(kind, value)
-
-      with FakeObj() as obj:
-        raise Exception("This Exception will be logged as critical and backtracked.")
+  """The ``laboro.error.handler.Handler`` is a singleton that logs every event given to its ``handle_error()`` method.
   """
 
   @staticmethod
   def handle_error(name, session, kind, value):
-    """Log the given error with its traceback and exit with exit code 1."""
+    """Log the given error with its traceback and exit.
+
+    Arguments:
+      name: A string specifying the ``laboro.workflow.Workflow`` instance name.
+      session: A string specifying the ``laboro.workflow.Workflow`` instance session.
+      kind: The `kind` of event. The type of `kind` is variable.
+      value: The value of the event. The type of `value` depends on `kind`.
+    """
     level = logging.INFO
     exit_msg = "Exited"
     exit_code = 0
