@@ -6,7 +6,7 @@ from laboro.logger import LaboroLogger
 
 
 class Manager:
-  """The purpose of the ``laboro.logger.manager.Manager`` object is to configure the logger used in the whole Laboro package and all its subpackages.
+  """The purpose of the ``laboro.logger.manager.Manager`` object is to configure the logger used in the whole **Laboro** package and all its subpackages.
   """
 
   terms = ["linux", "xterm", "xterm-256color"]
